@@ -1,13 +1,12 @@
-import os
-from typing import List, Tuple, Set
 import glob
+from typing import List, Tuple
 
 from itb.collection import to_upper
 
 
 def find_images(
-        directory: str,
-        images_extensions: Tuple[str] = ("jpg", "jpeg", "png", "bmp", "gif", "webp")
+    directory: str,
+    images_extensions: Tuple[str] = ("jpg", "jpeg", "png", "bmp", "gif", "webp"),
 ) -> List[str]:
     """
     Recursively find images in the given directory.
@@ -16,16 +15,11 @@ def find_images(
     lowercase and uppercase set of extensions.
     :return: the list of found images paths.
     """
-    return find_files(
-        directory,
-        images_extensions + tuple(to_upper(images_extensions))
-    )
+    return find_files(directory, images_extensions + tuple(to_upper(images_extensions)))
 
 
 def find_files(directory: str, extensions: Tuple[str]) -> List[str]:
     found_files = []
     for ext in extensions:
-        found_files.extend(
-            list(glob.glob(f"{directory}/**/*.{ext}", recursive=True))
-        )
+        found_files.extend(list(glob.glob(f"{directory}/**/*.{ext}", recursive=True)))
     return found_files
